//--------------------------------------------------------------
//
// Eamon Revolutions Role Playing Game
// Derek C. Jeter
//
//--------------------------------------------------------------

function XConsole(consoleID, defaultTextClassNameParam, maxTextBlocksParam)
{
    var divConsole = $('#' + consoleID);
    var defaultTextClassName = defaultTextClassNameParam;
    var maxTextBlocks = maxTextBlocksParam;
    var textBuffer = new Array();
    var textBlockCounter = 1;

    // Buffered write operations

    this.write = function(txt, color, className, pause)
    {
        var t = new Object();

        t.txt = txt;
        t.color = color;
        t.className = className;
        t.pause = pause;

        textBuffer.push(t);
    };

    this.writeLine = function(txt, color, className, pause)
    {
        this.write(txt + "<br/>", color, className, pause);
    };

    this.writeBlankLine = function()
    {
        // Prevent excessive blank lines
        var l = textBuffer.length;
        if (l >= 2 && textBuffer[l - 1].txt == "<br/>" && textBuffer[l - 1].txt == "<br/>")
        {
            return;
        }

        this.write("<br/>");
    };

    this.writeRuleLine = function()
    {
        this.write("<hr/>");
    };

    this.prompt = function(message, defaultValue, allowedValues)
    {
        while (true)
        {
            var r = prompt(message, defaultValue);
            
            if (r == null)
            {
                return null;
            }
            
            for (var i = 0; i < allowedValues.length; i++)
            {
                if (r.toLowerCase() == allowedValues[i].toLowerCase())
                {
                    return r;
                }
            }
        }
    };

    this.log = function(t)
    {
        try
        {
            if (console) console.log(t);
        }
        catch(e) {} 

        if (window.external && window.external.writeLine) window.external.writeLine(t);
    };
    
    // Async write the buffer to the console
    this.flush = function()
    {
        if (textBuffer.length == 0)
        {
            return;
        }

        window.setTimeout(flushNextItem, 0);
    };

    // Private method for async buffer flush

    function flushNextItem()
    {
        var t = textBuffer.shift();

        if (t == undefined) return;

        var newID = "TB_" + consoleID + "_" + textBlockCounter.toString();

        $('#' + newID).remove();

        var tb = $("<div>");
        tb.html(t.txt);
        tb.css("display", "inline");
        tb.attr("id", newID);

        if (t.className)
        {
            tb.addClass(t.className);
        }
        else
        {
            tb.addClass(defaultTextClassName);
        }

        if (t.color)
        {
            tb.css('color', t.color);
        }

        textBlockCounter++;

        if (textBlockCounter > maxTextBlocks)
        {
            textBlockCounter = 1;
        }

        divConsole.append(tb);

        var delayTime = 0;

        if (t.pause) //TODO: Pausing doesn't work
        {
            delayTime = t.pause * 1000;
        }

        if (textBuffer.length > 0)
        {
            window.setTimeout(flushNextItem, delayTime);

            if (delayTime > 0)
            {
                // Need to go ahead and force a scroll so delayed text is visible
                divConsole.scrollTop(divConsole.get(0).scrollHeight);
            }
        }
        else
        {
            divConsole.scrollTop(divConsole.get(0).scrollHeight);
        }
    }
}
