﻿//--------------------------------------------------------------
//
// Eamon Revolutions Role Playing Game
// Derek C. Jeter
//
//--------------------------------------------------------------

var CPersonalityType = new function () {
    this.friend = 3;
    this.enemy = 1;
    this.neutral = 2;
    this.max = 3;
};

var CGender = new function()
{
    this.male = 0;
    this.female = 1;

    this.getDisplayText = function(g)
    {
        if (g == this.male)
        {
            return "Male";
        }
        else
        {
            return "Female";
        }
    }
}

var CLocationType = new function()
{
    this.carriedByPlayer = "P";
    this.wornByPlayer = "W";
    this.carriedByMonster = "M";
    this.wornByMonster = "X";
    this.containedInArtifact = "C";
    this.hidden = "H";
    this.embedded = "E";
    this.room = "R";
}

var CArmorType = new function()
{
    this.shield = 1;
    this.leather = 2;
    this.chain = 4;
    this.plate = 6;
    this.magic = 8;
}

var CWeaponType = new function()
{
    this.axe = 1;
    this.missile = 2;
    this.club = 3;
    this.spear = 4;
    this.sword = 5;
}

var CArtifactType = new function()
{
    this.gold = 0;
    this.treasure = 1;
    this.weapon = 2;
    this.magicWeapon = 3;
    this.container = 4;
    this.lightable = 5;
    this.drinkable = 6;
    this.readable = 7;
    this.doorGate = 8;
    this.edible = 9;
    this.boundMonster = 10;
    this.wearable = 11;
    this.disguisedMonster = 12;
    this.deadBody = 13;
}

var CTargetType = new function()
{
    this.monster = 0;
    this.artifact = 1;
}

var COpenStatus = new function()
{
    this.open = 0;
    this.closed = 1;
    this.disallow = 2;
    this.smashed = 3;
    this.cannotBeOpened = 4;

    this.fromData = function(d, openValue, closedValue)
    {
        if (d > 1000)
        {
            return this.closed; // Has to be smashed open
        }

        switch(d)
        {
            case -2:
                return this.smashed;
            case openValue:
                return this.closed;
            case closedValue:
                return this.open;
            default:
                return this.disallow;
        }
    }
}

var CColorMapper = new function()
{
    this.map = function(code)
    {
        switch(code)
        {
            case "01":
                return "blue";
            case "02":
                return "green";
            case "03":
                return "cyan";
            case "04":
                return "red";
            case "05":
                return "purple";
            case "06":
                return "brown";
            case "07":
                return "white";
            case "08":
                return "gray";
            case "09":
                return "lightBlue";
            case "10":
                return "lightGreen";
            case "11":
                return "lightCyan";
            case "12":
                return "lightRed";
            case "13":
                return "lightPurple";
            case "14":
                return "yellow";
            default:
                return "white";
        }
    }
}

var CDirectionMapper = new function()
{
    this.mapName = function(name)
    {
        switch(name)
        {
            case "north":
                return 0;
            case "south":
                return 1;
            case "east":
                return 2;
            case "west":
                return 3;
            case "up":
                return 4;
            case "down":
                return 5;
            case "ne":
                return 6;
            case "nw":
                return 7;
            case "se":
                return 8;
            case "sw":
                return 9;
            default:
                return null;
        }
    }

    this.mapDirection = function(direction)
    {
        switch(direction)
        {
            case 0:
                return "north";
            case 1:
                return "south";
            case 2:
                return "east";
            case 3:
                return "west";
            case 4:
                return "up";
            case 5:
                return "down";
            case 6:
                return "northeast";
            case 7:
                return "northwest";
            case 8:
                return "southeast";
            case 9:
                return "southwest";
            default:
                return "";
        }
    }
}

var CCharacterFactory = new function()
{
    this.createEmptyCharacter = function()
    {
        var char = {
            name: "",
            gender: CGender.male,
            spellAbilities: { blast: 0, heal: 0, speed: 0, power: 0 },
            weaponAbilities: { axe: 5, missile: -10, club: 20, spear: 10, sword: 0 },
            gold: 200,
            bank: 0,
            hardiness: 0,
            agility: 0,
            charisma: 0,
            armorExpertise: 0,
            inventory: []
        };

        return char;
    };

    this.spawnSorsha = function()
    {
        var char = this.spawnBrutus();

        char.name = "Sorsha Spellslinger";
        char.gender = CGender.female;

        return char;
    };

    this.spawnBrutus = function()
    {
        var char = {
            name: "Brutus the Basher",
            gender: CGender.male,
            spellAbilities: { blast: 50, heal: 50, speed: 50, power: 50 },
            weaponAbilities: { axe: 50, missile: 50, club: 50, spear: 50, sword: 50 },
            gold: 20,
            bank: 1000,
            hardiness: 10,
            agility: 10,
            charisma: 20,
            armorExpertise: 50,
            inventory:
            [
                {
                    name: "Holy Avenger",
                    description: "This is your Holy Avenger sword.",
                    type: CArtifactType.magicWeapon,
                    weaponType: CWeaponType.sword,
                    complexity: 35,
                    dice: 3,
                    sides: 12,
                    weight: 12,
                    value: 500,
                    locationDetail: {
                        type: CLocationType.carriedByPlayer,
                        number: 0
                    }
                },
                {
                    name: "Dagger",
                    description: "This is your dagger.",
                    type: CArtifactType.weapon,
                    weaponType: CWeaponType.sword,
                    complexity: 0,
                    dice: 1,
                    sides: 4,
                    weight: 2,
                    value: 3,
                    locationDetail: {
                        type: CLocationType.carriedByPlayer,
                        number: 0
                    }
                },
                {
                    name: "Plate Mail",
                    description: "This is your plate mail armor.",
                    type: CArtifactType.wearable,
                    armorType: CArmorType.plate,
                    armorClass: 6,
                    weight: 20,
                    value: 150,
                    locationDetail: {
                        type: CLocationType.wornByPlayer,
                        number: 0
                    }
                },
                {
                    name: "Dragonscale Shield",
                    description: "This is your shield.",
                    type: CArtifactType.wearable,
                    armorType: CArmorType.shield,
                    armorClass: 1,
                    weight: 6,
                    value: 750,
                    locationDetail: {
                        type: CLocationType.wornByPlayer,
                        number: 0
                    }
                }
            ]
        };

        return char;
    }
};

var CmdResultFactory = new function()
{
    // Return status to use for a command error. No counters are incremented, room description isn't output, monsters don't take action.
    this.error = function()
    {
        return {
            inhibitRoundAdvance: true,
            inhibitEncounter: true,
            inhibitDescription: true
        }
    }

    // Return status to use for normal command execution. Counters are incremented, room description is NOT output, monsters take action.
    this.ok = function()
    {
        return {
            inhibitRoundAdvance: false,
            inhibitEncounter: false,
            inhibitDescription: true
        }
    }

    // Return status to use for normal command execution. Counters are incremented, room description IS output, monsters take action.
    // Typically used after navigation.
    this.okVerbose = function()
    {
        return {
            inhibitRoundAdvance: false,
            inhibitEncounter: false,
            inhibitDescription: false
        }
    }

    // Return status for changing rooms. Counters are incremented, room description IS output, monsters DO NOT take action.
    this.nav = function()
    {
        return {
            inhibitRoundAdvance: false,
            inhibitEncounter: false,
            inhibitDescription: false
        }
    }

    // Return status for management/debug commands. Counters are NOT incremented, room description IS output, monsters DO NOT take action.
    this.mgmt = function()
    {
        return {
            inhibitRoundAdvance: true,
            inhibitEncounter: true,
            inhibitDescription: false
        }
    }
}

String.prototype.capitalize = function()
{
    return this.substr(0, 1).toUpperCase() + this.substr(1);
}

String.prototype.endsWithS = function()
{
    return (this.toLowerCase().charAt(artifact.name.length - 1) == 's');
}

Number.prototype.clamp = function(min, max)
{
    return Math.min(Math.max(this, min), max);
};