//--------------------------------------------------------------
//
// Eamon Revolutions Role Playing Game
// Derek C. Jeter
//
//--------------------------------------------------------------

function XRndNum() 
{  
    // Returns a random number between 1 and n, inclusive
    this.generate = function(n)
    {
        return (Math.floor(Math.random() * n + 1));
    };

    // Returns a random number between min and max, inclusive
    this.range = function(min, max)
    {
        return Math.floor(Math.random() * (max - min + 1)) + min;
    };
    
    // Simulates die roll -- XRndNum.roll(3, 8) is same as "3d8"
    this.roll = function(dice, sides)
    {
        var sum = 0;
        for (var i = 1; i <= dice; i++)
        {
            sum += this.generate(sides);
        }
        return sum;
    };
    
    // Rolls 1d100 and if the roll <= chance, return true
    this.checkPct = function(chance)
    {
        return (this.generate(100) <= chance);
    };

    this.shuffle = function(x)
    {
        return _.shuffle(x);
    };

    // Given an object with percentage probabilities, randomly
    // selects one choice after rolling percentile dice:
    //
    // var choices = { larry: 50, moe: 25, curly: 25 };
    //
    // 50% chance of rolling 'larry', or 25% chance for moe or curly
    //
    // Returns the key of the randomly picked choice
    //
    this.pickChoice = function(choices)
    {
        var ranges = [];
        var lowerBound = 0;

        _.each(_.keys(choices), function(key)
        {
            var pct = choices[key];

            var range =
            {
                name: key,
                upperBound: pct + lowerBound
            };

            ranges.push(range);

            lowerBound = range.upperBound;
        });

        ranges = _.sortBy(ranges, 'upperBound');

        var roll = this.generate(100);

        var chosen = _.find(ranges, function(x) { return (roll <= x.upperBound); });

        return chosen.name;
    };
}