﻿var Validator = function()
{
    var self = this;

    self.errorObjectType = {
        artifact: 'a',
        room: 'r',
        module: 'x',
        monster: 'm',
        effect: 'e'
    };

    self.severity = {
        error: 'e',
        warn: 'w'
    };

    self.module = null;

    // --- Module rules ---

    self.moduleRules =
    [
        /* Check for invalid info block */
        function(module, errors)
        {
            if (!_.isObject(module.info))
            {
                errors.push(new self.Error(self.errorObjectType.module, '?', "Module contains invalid info property"));
            }
        },
        /* Check for invalid module name */
        function(module, errors)
        {
            if (!_.isString(module.name) || _.isEmpty(module.name))
            {
                errors.push(new self.Error(self.errorObjectType.module, module.info.serialNum, "Module contains invalid name property"));
            }
        },
        /* Check for invalid module intro */
        function(module, errors)
        {
            if (!_.isString(module.intro) || _.isEmpty(module.intro))
            {
                errors.push(new self.Error(self.errorObjectType.module, module.info.serialNum, "Module contains invalid intro property"));
            }
        },
        /* Check for invalid module author */
        function(module, errors)
        {
            if (!_.isString(module.info.author) || _.isEmpty(module.info.author))
            {
                errors.push(new self.Error(self.errorObjectType.module, module.info.serialNum, "Module contains invalid info.author property"));
            }
        },
        /* Check for rooms */
        function(module, errors)
        {
            if (!_.isArray(module.rooms) || _.isEmpty(module.rooms))
            {
                errors.push(new self.Error(self.errorObjectType.module, module.info.serialNum, "Module has no Rooms"));
            }
        },
        /* Check for artifacts */
        function(module, errors)
        {
            if (!_.isArray(module.artifacts) || _.isEmpty(module.artifacts))
            {
                errors.push(new self.Error(self.errorObjectType.module, module.info.serialNum, "Module has no Artifacts"));
            }
        },
        /* Check for monsters */
        function(module, errors)
        {
            if (!_.isArray(module.monsters) || _.isEmpty(module.monsters))
            {
                errors.push(new self.Error(self.errorObjectType.module, module.info.serialNum, "Module has no Monsters"));
            }
        },
        /* Check for effects */
        function(module, errors)
        {
            if (!_.isArray(module.effects) || _.isEmpty(module.effects))
            {
                errors.push(new self.Error(self.errorObjectType.module, module.info.serialNum, "Module has no Effects"));
            }
        },
        /* Check for any dark rooms but no light artifact */
        function(module, errors)
        {
            var hasDarkRooms = _.some(module.rooms, function(r) { return r.isDark; });
            
            if (hasDarkRooms)
            {
                var hasLightArtifact = _.some(module.artifacts, function(a) { return (a.type == CArtifactType.lightable); });

                if (!hasLightArtifact)
                {
                    errors.push(new self.Error(self.errorObjectType.module, module.info.serialNum, "Module has dark room(s) but no lightable artifact(s)"));
                }
            }
        },
        /* Check for adventure exit */
        function(room, module, errors)
        {

        }
    ];

    // --- Room rules ---

    self.roomRules =
    [
        /* Check room connections */
        function(room, module, errors)
        {

        },
        
    ];

    // --- Artifact rules ---

    self.artifactRules =
    [
    ];

    // --- Monster rules ---

    self.monsterRules =
    [
    ];

    // --- Effect rules ---

    self.effectRules =
    [
    ];

    self.validateModule = function(module)
    {
        var errors = [];

        _.each(self.moduleRules, function(rule)
        {
            rule.call(self, module, errors)
        })

        _.each(module.rooms, function(room)
        {
            _.each(self.roomRules, function(rule)
            {
                rule.call(self, room, module, errors)
            })
        });

        _.each(module.artifacts, function(artifact)
        {
            _.each(self.artifactRules, function(rule)
            {
                rule.call(self, artifact, module, errors)
            })
        });

        _.each(module.monsters, function(monster)
        {
            _.each(self.monsterRules, function(rule)
            {
                rule.call(self, monster, module, errors)
            })
        });

        _.each(module.effects, function(effect)
        {
            _.each(self.effectRules, function(rule)
            {
                rule.call(self, effect, module, errors)
            })
        });

        return errors;
    };

    self.Error = function(type, number, msg)
    {
        return {
            type: type,
            number: number,
            message: msg,
            severity: self.severity.error
        };
    };
};
