// Test fixtures

QUnit.test("Game Engine - printDescription() - no color code", function (assert)
{
    var testText = "The Wonderful World of Eamon";
    var testColor = "red";

    var mockConsole = new MockGameConsole();
    var gameStateData = MockGameStateFactory.createBasicGameState();

    var ge = new XGameEngine();

    ge.initialize(mockConsole, null, gameStateData, null);

    ge.printDescription(testText, testColor);

    assert.equal(mockConsole.buffer.length, 1, "Mock console buffer length");
    assert.equal(mockConsole.buffer[0].text, testText, "Text");
    assert.equal(mockConsole.buffer[0].color, testColor, "Color");
});

QUnit.test("Game Engine - printDescription() - with color code", function (assert) {
    var testText = "The Wonderful World of Eamon{05}";
    var testColor = "purple";

    var mockConsole = new MockGameConsole();
    var gameStateData = MockGameStateFactory.createBasicGameState();

    var ge = new XGameEngine();

    ge.initialize(mockConsole, null, gameStateData, null);

    ge.printDescription(testText, "");

    assert.equal(mockConsole.buffer.length, 1, "Mock console buffer length");
    assert.equal(mockConsole.buffer[0].text, "The Wonderful World of Eamon", "Text");
    assert.equal(mockConsole.buffer[0].color, testColor, "Color");
});

QUnit.test("Game Engine - printEffect() - chained, no line break", function (assert)
{    
    var mockConsole = new MockGameConsole();
    var gameStateData = MockGameStateFactory.createBasicGameState();

    gameStateData.gameModule.effects.push({
        number: 1,
        description: "effect A**004"
    });

    gameStateData.gameModule.effects.push({
        number: 4,
        description: "effect B{05}"
    });

    var ge = new XGameEngine();

    ge.initialize(mockConsole, null, gameStateData, null);

    ge.printEffect(1);

    assert.equal(mockConsole.buffer.length, 2, "Mock console buffer length");
    assert.equal(mockConsole.buffer[0].text, "effect A", "Text");
    assert.equal(mockConsole.buffer[0].color, "green", "Color");
    assert.equal(mockConsole.buffer[0].lineBreak, false, "Line Break");
    assert.equal(mockConsole.buffer[1].text, "effect B", "Text");
    assert.equal(mockConsole.buffer[1].color, "purple", "Color");
    assert.equal(mockConsole.buffer[1].lineBreak, true, "Line Break");
});

QUnit.test("Game Engine - printEffect() - chained, with line break", function (assert) {
    var mockConsole = new MockGameConsole();
    var gameStateData = MockGameStateFactory.createBasicGameState();

    gameStateData.gameModule.effects.push({
        number: 1,
        description: "effect A*004"
    });

    gameStateData.gameModule.effects.push({
        number: 4,
        description: "effect B{05}"
    });

    var ge = new XGameEngine();

    ge.initialize(mockConsole, null, gameStateData, null);

    ge.printEffect(1);

    assert.equal(mockConsole.buffer.length, 2, "Mock console buffer length");
    assert.equal(mockConsole.buffer[0].text, "effect A", "Text");
    assert.equal(mockConsole.buffer[0].color, "green", "Color");
    assert.equal(mockConsole.buffer[0].lineBreak, true, "Line Break");
    assert.equal(mockConsole.buffer[1].text, "effect B", "Text");
    assert.equal(mockConsole.buffer[1].color, "purple", "Color");
    assert.equal(mockConsole.buffer[1].lineBreak, true, "Line Break");
});
